@@ -49,7 +49,10 @@ class Repeated:
 
     def append(self, value):
         if not self.checker or self.checker(value):
-            self.pb_field.append(value)
+            if self.py_type and isinstance(value, self.py_type):
+                self.pb_field.append(value.pb)
+            else:
+                self.pb_field.append(value)
 
 
 class Link:
