@@ -252,7 +252,7 @@ class PreseemApiKey(object):
     def __init__(self, api_key, token):
         self.api_key = api_key
         self._hdr = {'Authorization': f'token {token}'}
-        self._loaded = 0
+        self._loaded = None
         self._data = {}
         self._api = None
 
@@ -277,7 +277,7 @@ class PreseemApiKey(object):
             self._api = HttpClient('https://app.preseem.com', verify_ssl=False)
 
         now = asyncio.get_event_loop().time()
-        if self._loaded + 3600 > now:
+        if self._loaded and self._loaded + 3600 > now:
             return
         self._data = await self._api.request('/api/v2/api-key-lookup/',
                                              headers=self._hdr,
